@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,11 +63,7 @@ private:
 	void button_toggled(GtkToggleButton* button);
 	void menu_hidden();
 	void configure();
-#if (LIBXFCE4PANEL_CHECK_VERSION(4,9,0))
 	void mode_changed(XfcePanelPlugin*, XfcePanelPluginMode mode);
-#else
-	void orientation_changed(XfcePanelPlugin*, GtkOrientation orientation);
-#endif
 	gboolean remote_event(XfcePanelPlugin*, gchar* name, GValue* value);
 	void save();
 	void show_about();
